Load — Glances 2.8.3 documentation

# Load

Availability: Unix

On the No Sheep blog, Zachary Tirrell defines the load average:

> “In short it is the average sum of the number of processes waiting in the run-queue plus the number currently executing over 1, 5, and 15 minutes time periods.”

Glances gets the number of CPU core to adapt the alerts. Alerts on load average are only set on 15 minutes time period. The first line also displays the number of CPU core.

Legend:

Load avg | Status
--- | ---
`<0.7*core` | `OK`
`>0.7*core` | `CAREFUL`
`>1*core` | `WARNING`
`>5*core` | `CRITICAL`

Note

Limit values can be overwritten in the configuration file under the `[load]` section.